"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Branch = void 0;
const commit_1 = require("../Commit/commit");
const GitlabApiClientBase_1 = require("../GitlabApiClientBase");
const gitlabApiClientBase_1 = require("../GitlabApiClientBase/gitlabApiClientBase");
const mergeRequest_1 = require("../MergeRequest/mergeRequest");
const pipeline_1 = require("../Pipeline/pipeline");
class Branch extends gitlabApiClientBase_1.GitlabApiClientBase {
    constructor(branchInfo, options, projectId) {
        super(options);
        this.projectId = projectId;
        this.projectId = projectId;
        Object.assign(this, branchInfo);
    }
    getMergeRequest() {
        return __awaiter(this, void 0, void 0, function* () {
            const customSearchOptions = {
                source_branch: this.name,
                state: "opened",
            };
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.projectId}/merge_requests`,
                method: GitlabApiClientBase_1.Methods.GET,
                expectedStatusCode: 200,
                params: customSearchOptions,
            });
            return data[0] ? new mergeRequest_1.MergeRequest(data[0], this.options) : null;
        });
    }
    findCommits(searchOptions = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.projectId}/repository/commits`,
                method: GitlabApiClientBase_1.Methods.GET,
                expectedStatusCode: 200,
                params: Object.assign(Object.assign({}, searchOptions), { ref_name: this.name }),
            });
            return data.map((commitInfo) => new commit_1.Commit(commitInfo, this.options, this.projectId, this.name));
        });
    }
    findPipelines(searchOptions = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.projectId}/pipelines`,
                method: GitlabApiClientBase_1.Methods.GET,
                expectedStatusCode: 200,
                params: Object.assign(Object.assign({}, searchOptions), { ref_name: this.name }),
            });
            return data.map((pipelineInfo) => new pipeline_1.Pipeline(pipelineInfo, this.options));
        });
    }
    createPipeline() {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.projectId}/pipeline`,
                method: GitlabApiClientBase_1.Methods.POST,
                expectedStatusCode: 201,
                data: { ref: this.name },
            });
            return new pipeline_1.Pipeline(data, this.options);
        });
    }
    createMergeRequest(mergeRequestInfo) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.projectId}/merge_requests`,
                method: GitlabApiClientBase_1.Methods.POST,
                expectedStatusCode: 201,
                data: Object.assign(Object.assign({}, mergeRequestInfo), { source_branch: this.name }),
            });
            return new mergeRequest_1.MergeRequest(data, this.options);
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.CallGitlabApi({
                endpoint: `/projects/${this.projectId}/repository/branches/${this.name}`,
                method: GitlabApiClientBase_1.Methods.DELETE,
                expectedStatusCode: 204,
            });
        });
    }
}
exports.Branch = Branch;
