"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Gitlab = void 0;
const options_1 = require("../utils/options");
const gitlabApiClientBase_1 = require("../GitlabApiClientBase/gitlabApiClientBase");
const GitlabApiClientBase_1 = require("../GitlabApiClientBase");
const project_1 = require("../Project/project");
const group_1 = require("../Group/group");
const user_1 = require("../User/user");
const defaultOptions = {
    privateToken: process.env.GITLAB_TOKEN || "",
    cache: false,
    gitlabUrl: "https://gitlab.com",
};
class Gitlab extends gitlabApiClientBase_1.GitlabApiClientBase {
    constructor(partialOptions) {
        const options = partialOptions
            ? (0, options_1.getOptions)(partialOptions, defaultOptions)
            : defaultOptions;
        if (!options.privateToken)
            throw new Error("Gitlab Token is required. Either provide it in the constructor or set it as an environment variable: GITLAB_TOKEN");
        super(options);
        this.options = options;
    }
    resetCache() {
        if (!this.options.cache)
            return console.warn("Cache is not enabled.");
        super.resetCacheInternal();
    }
    findProjects(searchOptions = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: "/projects",
                method: GitlabApiClientBase_1.Methods.GET,
                params: searchOptions,
                expectedStatusCode: 200,
            });
            return data.map((project) => new project_1.Project(project, this.options));
        });
    }
    findGroups(searchOptions = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: "/groups",
                method: GitlabApiClientBase_1.Methods.GET,
                expectedStatusCode: 200,
                params: searchOptions,
            });
            return data.map((group) => new group_1.Group(group, this.options));
        });
    }
    findUsers(searchOptions = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: "/users",
                method: GitlabApiClientBase_1.Methods.GET,
                expectedStatusCode: 200,
                params: searchOptions,
            });
            return data.map((userInfo) => new user_1.RestrictedUser(userInfo));
        });
    }
    createProject(projectOptions) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: "/projects",
                method: GitlabApiClientBase_1.Methods.POST,
                expectedStatusCode: 201,
                params: projectOptions,
            });
            return new project_1.Project(data, this.options);
        });
    }
    createGroup(groupName) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: "/groups",
                method: GitlabApiClientBase_1.Methods.POST,
                expectedStatusCode: 201,
                params: groupName,
            });
            return new group_1.Group(data, this.options);
        });
    }
}
exports.Gitlab = Gitlab;
