"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitlabApiClientBase = void 0;
const _1 = require(".");
const axios_1 = __importDefault(require("axios"));
const lodash_1 = __importDefault(require("lodash"));
const user_1 = require("../User/user");
const axiosMethods = {
    GET: axios_1.default.get,
    POST: axios_1.default.post,
    PUT: axios_1.default.put,
    DELETE: axios_1.default.delete,
    PATCH: axios_1.default.patch,
};
const cachedRequests = [];
class GitlabApiClientBase {
    constructor(options) {
        this.options = options;
        this.options = options;
    }
    resetCacheInternal() {
        if (!this.options.cache)
            return;
        while (cachedRequests.length) {
            cachedRequests.pop();
        }
    }
    CallGitlabApi(options) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.options.cache) {
                for (const cachedRequest of cachedRequests) {
                    if (lodash_1.default.isEqual(cachedRequest[0], options)) {
                        return cachedRequest[1];
                    }
                }
            }
            let response;
            try {
                if (options.method === _1.Methods.FORM_POST) {
                    const data = new URLSearchParams();
                    if (options.data && typeof options.data === "object") {
                        for (const [key, value] of Object.entries(options.data)) {
                            data.append(key, value);
                        }
                    }
                    const url = new URL(`${this.options.gitlabUrl.replace(/\/$/, "")}/api/v4${options.endpoint}`);
                    if (options.params) {
                        for (const [key, value] of Object.entries(options.params)) {
                            url.searchParams.append(key, value);
                        }
                    }
                    const res = yield fetch(url, {
                        body: data,
                        headers: {
                            "PRIVATE-TOKEN": this.options.privateToken,
                            "Content-Type": "application/x-www-form-urlencoded",
                        },
                        method: "POST",
                    });
                    response = {
                        status: res.status,
                        data: yield res.json(),
                        headers: res.headers,
                    };
                }
                else {
                    response = yield axiosMethods[options.method](`${this.options.gitlabUrl.replace(/\/$/, "")}/api/v4${options.endpoint}`, {
                        headers: Object.assign({ "PRIVATE-TOKEN": this.options.privateToken }, (options.headers || {})),
                        data: options.data,
                        params: options.params,
                    });
                }
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
            }
            catch (err) {
                if (err.response) {
                    response = err.response;
                }
                else {
                    throw err;
                }
            }
            if (response.status === 401) {
                throw new Error(`Request with the following Options is unauthorized:\n${JSON.stringify(options, null, 2)};\nResponse:\n${JSON.stringify(response.data || {}, null, 2)}`);
            }
            else if (response.status >= 500) {
                throw new Error(`Gitlab responded with a ${response.status} status code. Please try again later:\n${JSON.stringify(response.data || {}, null, 2)}`);
            }
            else if (response.status !== options.expectedStatusCode) {
                throw new Error(`Gitlab responded with a ${response.status} status code:\nRequest: ${JSON.stringify(options || {}, null, 2)}\nResponse: ${JSON.stringify(response.data || {}, null, 2)}`);
            }
            const customResponse = {
                statusCode: response.status,
                headers: response.headers,
                data: response.data,
            };
            if (this.options.cache)
                cachedRequests.push([options, customResponse]);
            return customResponse;
        });
    }
    getUser() {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: "/user",
                method: _1.Methods.GET,
                expectedStatusCode: 200,
            });
            return new user_1.User(data);
        });
    }
}
exports.GitlabApiClientBase = GitlabApiClientBase;
