"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Job = void 0;
const gitlabApiClientBase_1 = require("../GitlabApiClientBase/gitlabApiClientBase");
const commit_1 = require("../Commit/commit");
const pipeline_1 = require("../Pipeline/pipeline");
const GitlabApiClientBase_1 = require("../GitlabApiClientBase");
class Job extends gitlabApiClientBase_1.GitlabApiClientBase {
    constructor(jobInfo, options, projectId) {
        super(options);
        this.projectId = projectId;
        this.commit = new commit_1.Commit(jobInfo.commit, options, projectId);
        this.pipeline = new pipeline_1.Pipeline(jobInfo.pipeline, options);
        this.projectId = projectId;
        Object.assign(this, jobInfo);
    }
    downloadArtifacts() {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.projectId}/jobs/${this.id}/artifacts`,
                method: GitlabApiClientBase_1.Methods.GET,
                expectedStatusCode: 200,
            });
            return data;
        });
    }
    cancel() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.CallGitlabApi({
                endpoint: `/projects/${this.projectId}/jobs/${this.id}/cancel`,
                method: GitlabApiClientBase_1.Methods.POST,
                expectedStatusCode: 201,
            });
        });
    }
    retry() {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.projectId}/jobs/${this.id}/retry`,
                method: GitlabApiClientBase_1.Methods.POST,
                expectedStatusCode: 201,
            });
            return new Job(data, this.options, this.projectId);
        });
    }
    erase() {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.projectId}/jobs/${this.id}/erase`,
                method: GitlabApiClientBase_1.Methods.POST,
                expectedStatusCode: 201,
            });
            Object.assign(this, data);
        });
    }
    play(jobVariablesAttributes) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.CallGitlabApi({
                endpoint: `/projects/${this.projectId}/jobs/${this.id}/play`,
                method: GitlabApiClientBase_1.Methods.POST,
                expectedStatusCode: 201,
                data: { job_variables_attributes: jobVariablesAttributes },
            });
        });
    }
}
exports.Job = Job;
