"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MergeRequest = void 0;
const branch_1 = require("../Branch/branch");
const GitlabApiClientBase_1 = require("../GitlabApiClientBase");
const gitlabApiClientBase_1 = require("../GitlabApiClientBase/gitlabApiClientBase");
const pipeline_1 = require("../Pipeline/pipeline");
class MergeRequest extends gitlabApiClientBase_1.GitlabApiClientBase {
    constructor(mergeRequestInfo, options) {
        super(options);
        Object.assign(this, mergeRequestInfo);
    }
    getBranch() {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.project_id}/repository/branches/${this.source_branch}`,
                method: GitlabApiClientBase_1.Methods.GET,
                expectedStatusCode: 200,
            });
            return new branch_1.Branch(data, this.options, this.project_id);
        });
    }
    findPipelines(searchOptions = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.project_id}/pipelines`,
                method: GitlabApiClientBase_1.Methods.GET,
                expectedStatusCode: 200,
                params: Object.assign(Object.assign({}, searchOptions), { ref_name: this.source_branch }),
            });
            return data.map((pipelineInfo) => new pipeline_1.Pipeline(pipelineInfo, this.options));
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.project_id}/merge_requests/${this.iid}`,
                method: GitlabApiClientBase_1.Methods.DELETE,
                expectedStatusCode: 204,
            });
            Object.assign(this, data);
        });
    }
    merge() {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.project_id}/merge_requests/${this.iid}/merge`,
                method: GitlabApiClientBase_1.Methods.PUT,
                expectedStatusCode: 200,
            });
            Object.assign(this, data);
        });
    }
}
exports.MergeRequest = MergeRequest;
