"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Pipeline = void 0;
const GitlabApiClientBase_1 = require("../GitlabApiClientBase");
const gitlabApiClientBase_1 = require("../GitlabApiClientBase/gitlabApiClientBase");
const job_1 = require("../Job/job");
class Pipeline extends gitlabApiClientBase_1.GitlabApiClientBase {
    constructor(pipelineInfo, options) {
        super(options);
        Object.assign(this, pipelineInfo);
    }
    findJobs(searchOptions = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.project_id}/pipelines/${this.id}/jobs`,
                method: GitlabApiClientBase_1.Methods.GET,
                expectedStatusCode: 200,
                params: searchOptions,
            });
            return data.map((jobInfo) => new job_1.Job(jobInfo, this.options, this.project_id));
        });
    }
    retry() {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.project_id}/pipelines/${this.id}/retry`,
                method: GitlabApiClientBase_1.Methods.POST,
                expectedStatusCode: 201,
            });
            return new Pipeline(data, this.options);
        });
    }
    cancel() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.CallGitlabApi({
                endpoint: `/projects/${this.project_id}/pipelines/${this.id}/cancel`,
                method: GitlabApiClientBase_1.Methods.POST,
                expectedStatusCode: 201,
            });
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.CallGitlabApi({
                endpoint: `/projects/${this.project_id}/pipelines/${this.id}`,
                method: GitlabApiClientBase_1.Methods.DELETE,
                expectedStatusCode: 204,
            });
        });
    }
}
exports.Pipeline = Pipeline;
