"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Project = void 0;
const branch_1 = require("../Branch/branch");
const commit_1 = require("../Commit/commit");
const file_1 = require("../File/file");
const GitlabApiClientBase_1 = require("../GitlabApiClientBase");
const gitlabApiClientBase_1 = require("../GitlabApiClientBase/gitlabApiClientBase");
const issue_1 = require("../Issue/issue");
const mergeRequest_1 = require("../MergeRequest/mergeRequest");
const pipeline_1 = require("../Pipeline/pipeline");
const base64_1 = require("../utils/base64");
class Project extends gitlabApiClientBase_1.GitlabApiClientBase {
    constructor(projectInfo, options) {
        super(options);
        Object.assign(this, projectInfo);
    }
    findBranches(searchOptions = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.id}/repository/branches`,
                method: GitlabApiClientBase_1.Methods.GET,
                expectedStatusCode: 200,
                params: searchOptions,
            });
            return data.map((branch) => new branch_1.Branch(branch, this.options, this.id));
        });
    }
    findMergeRequests(searchOptions = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.id}/merge_requests`,
                method: GitlabApiClientBase_1.Methods.GET,
                expectedStatusCode: 200,
                params: searchOptions,
            });
            return data.map((mergeRequest) => new mergeRequest_1.MergeRequest(mergeRequest, this.options));
        });
    }
    findCommits(searchOptions = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.id}/repository/commits`,
                method: GitlabApiClientBase_1.Methods.GET,
                expectedStatusCode: 200,
                params: searchOptions,
            });
            return data.map((commit) => new commit_1.Commit(commit, this.options, this.id));
        });
    }
    findPipelines(searchOptions = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.id}/pipelines`,
                method: GitlabApiClientBase_1.Methods.GET,
                expectedStatusCode: 200,
                params: searchOptions,
            });
            return data.map((pipeline) => new pipeline_1.Pipeline(pipeline, this.options));
        });
    }
    findIssues(searchOptions = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.id}/issues`,
                method: GitlabApiClientBase_1.Methods.GET,
                expectedStatusCode: 200,
                params: searchOptions,
            });
            return data.map((issue) => new issue_1.Issue(issue, this.options));
        });
    }
    getFile(filePath, ref) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.id}/repository/files/${filePath}`,
                method: GitlabApiClientBase_1.Methods.GET,
                expectedStatusCode: 200,
                params: { ref },
            });
            return new file_1.File(Object.assign(Object.assign({}, data), { content: (0, base64_1.decodeBase64)(data.content) }), this.options, this.id, ref);
        });
    }
    createBranch(branchName, sourceBranchName) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.id}/repository/branches?branch=${branchName}&ref=${sourceBranchName}`,
                method: GitlabApiClientBase_1.Methods.POST,
                expectedStatusCode: 201,
            });
            return new branch_1.Branch(data, this.options, this.id);
        });
    }
    createIssue(issue) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.id}/issues`,
                method: GitlabApiClientBase_1.Methods.POST,
                expectedStatusCode: 201,
                data: issue,
            });
            return new issue_1.Issue(data, this.options);
        });
    }
    archive() {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.id}/archive`,
                method: GitlabApiClientBase_1.Methods.POST,
                expectedStatusCode: 201,
            });
            Object.assign(this, data);
        });
    }
    unArchive() {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.CallGitlabApi({
                endpoint: `/projects/${this.id}/unarchive`,
                method: GitlabApiClientBase_1.Methods.POST,
                expectedStatusCode: 201,
            });
            Object.assign(this, data);
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.CallGitlabApi({
                endpoint: `/projects/${this.id}`,
                method: GitlabApiClientBase_1.Methods.DELETE,
                expectedStatusCode: 202,
            });
        });
    }
}
exports.Project = Project;
